#
# spec file for package cdemu-daemon
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir /var/adm/fillup-templates
%endif

Name:           cdemu-daemon
Version:        3.2.7
Release:        1.3
Summary:        Device daemon for cdemu, a virtual CD-ROM device emulator
License:        GPL-2.0-or-later
Group:          System/Daemons
URL:            https://cdemu.sourceforge.io/about/daemon/

#Git-Clone:	https://github.com/cdemu/cdemu
Source:         https://downloads.sf.net/cdemu/%name-%version.tar.xz
Source2:        60-vhba.rules
Source3:        cdemu-daemon.sysconfig
Source4:        cdemu-daemon.service
BuildRequires:  cmake >= 2.8.5
BuildRequires:  intltool >= 0.21
BuildRequires:  pkg-config >= 0.16
BuildRequires:  pkgconfig(ao) >= 0.8.0
BuildRequires:  pkgconfig(gio-2.0) >= 2.30
BuildRequires:  pkgconfig(glib-2.0) >= 2.30
BuildRequires:  pkgconfig(gmodule-2.0) >= 2.30
BuildRequires:  pkgconfig(gobject-2.0) >= 2.30
BuildRequires:  pkgconfig(gthread-2.0) >= 2.30
BuildRequires:  pkgconfig(libmirage) >= 3.2.0
Requires(pre):  %fillup_prereq
Requires:       vhba-kmp
Recommends:     %name-lang

%lang_package

%description
cdemu-daemon receives SCSI commands from kernel module thorugh the
VHBA module and processes them, passing the requested data back to
the kernel. The daemon implements the actual virtual device; one
instance per each device registered by kernel module. It uses
libmirage for the image access (e.g. sector reading).

The daemon registers itself on D-BUS's system or session bus
(depending on the options passed to it) where it exposes an interface
that can be used by clients to control it.

%prep
%autosetup -p1

%build
%cmake -DCMAKE_INSTALL_LIBEXECDIR:PATH="%_libexecdir"
%cmake_build

%install
b="%buildroot"
%cmake_install
mkdir -p "$b/%_sbindir" "$b/%_fillupdir" \
	"$b/%_prefix/lib/udev/rules.d"
install -pm0644 "%{S:2}" "$b/%_prefix/lib/udev/rules.d/60-vhba.rules"
install -pm0644 "%{S:3}" "$b/%_fillupdir/sysconfig.cdemu-daemon"
mkdir -p "$b/%_userunitdir"
install -pm0644 "%{S:4}" "$b/%_userunitdir/cdemu-daemon.service"
mkdir -p "$b/%_datadir/dbus-1/services"
install -pm0644 "service-example/net.sf.cdemu.CDEmuDaemon.service" "$b/%_datadir/dbus-1/services/net.sf.cdemu.CDEmuDaemon.service"
%find_lang %name

%post
%fillup_only

%files -f %name.lang
%doc README
%license COPYING
%_bindir/cdemu-daemon
%_mandir/man8/cdemu-daemon.8*
%_fillupdir/sysconfig.cdemu-daemon
%_prefix/lib/udev/
%_userunitdir/cdemu-daemon.service
%_datadir/dbus-1/services/net.sf.cdemu.CDEmuDaemon.service

%changelog
* Sun Aug 18 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 3.2.7
  * ``READ SUBCHANNEL`` command fixes
  * Implement ``SEEK`` command
  * Adjust error codes returned by read commands
* Thu Mar 14 2024 Jan Engelhardt <jengelh@inai.de>
- Add an explanation to the use of static_node
* Mon Mar 11 2024 Jan Engelhardt <jengelh@inai.de>
- Revert Feb 27 addition of static_node; this does not seemingly
  do anything.
* Tue Feb 27 2024 Matthias Bach <marix@marix.org>
- Fix cdemu-daemon startup failing for regular users due to not
  being able to trigger the load of the vhba kernel module.
  (boo#958517)
* Sat Feb  5 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 3.2.6
  * No user visible changes, just packaging-related.
* Sun Aug 29 2021 Yaroslav Kurlaev <yaroslav.kurlaev@gmail.com>
- Add systemd and D-Bus .service files
- Fix .spec file warning
* Tue Apr 20 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 3.2.5
  * Updated ISRC validation to match crdao documentation.
  * Remove bundled DBus activation scripts.
- Remove logfile.diff (no longer applicable)
* Fri May  1 2020 Aaron Stern <ukbeast89@protonmail.com>
- Update to release 3.2.4
  * Updated the list of commands that interrupt audio play.
  * Generate device serial number using global device number
    instead of local one.
  * Delay emulation: removed the use of deprecated GTimeVal.
  * Tweak default device identifier in standard INQUIRY response.
  * Implemented INQUIRY EVPD 0x83 page.
* Thu Oct 24 2019 Jan Engelhardt <jengelh@inai.de>
- Update to release 3.2.3
  * Updated the list of MMC commands that interrupt audio play.
* Wed Jul  3 2019 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 3.2.1
  * Added initial support for BluRay profile
  * Added initial support for BluRay writing
  * Extended READ DISC STRUCTURE for BluRay support
  * Moved the fabrication of disc structures from libMirage
    to cdemu-daemon.
  * Implemented READ DISC STRUCTURE format 0xFF (list of
    supported structures).
  * Removed the "dvd-report-css" flag as parser parameter and
    implemented it as device option.
  * Improved GET PERFORMANCE implementation: better argument
    checking, updated descriptors, and added BluRay support.
* Wed Apr 25 2018 p.seiler@linuxmail.org
- Changed vhba-kmp package from recommend to require for /dev/vhba_ctl
  * cdemu is not working if vhba kernel module is not installed
* Thu Nov 23 2017 rbrown@suse.com
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468)
* Mon Aug  7 2017 jengelh@inai.de
- Update to new upstream release 3.1.0
  * Added no-op implementation of RESERVE TRACK for all
    recording modes.
  * Added infrastructure for localization support.
  * Added Slovenian and Russian translations.
* Mon Feb  6 2017 jengelh@inai.de
- Update to new upstream release 3.0.5
  * Only updates for other distros
- New udev rules using the "uaccess" method
* Fri Jan 22 2016 jengelh@inai.de
- Update to new upstream release 3.0.4
  * Ensure "disc_closed" variable is set accordingly
* Mon Jan  4 2016 jengelh@inai.de
- Recommend vhba-kmp package for /dev/vhba_ctl [boo#960464]
* Mon Nov 23 2015 jengelh@inai.de
- Update to new upstream release 3.0.3
  * fixed a copy-and-paste error in feature initialization code
  * daemon: device: signal the Media Eject Request event only when
  device unload is requested via D-Bus API
- Run %%fillup and populate /etc/sysconfig/cdemu-daemon
- Drop cdemu_daemon_typo_in_mmc_packet_commands_h.patch (merged)
* Thu Feb 26 2015 normand@linux.vnet.ibm.com
- new cdemu_daemon_typo_in_mmc_packet_commands_h.patch
  to avoid ppc/ppc64 build failure
  related to upstream ticket https://sourceforge.net/p/cdemu/patches/22/
* Thu Oct  2 2014 jengelh@inai.de
- Update to new upstream release 3.0.2
  * properly report last session lead-in address as 0xFFFFFFFF on
  closed and non-recordable discs. Fixes "Used capacity" in K3B's
  Medium Information right after writing an image to the virtual
  disc.
  * fixed a typo that prevented CD-TEXT being recorded on any
  recording attempt beyond the first one
* Mon Sep 22 2014 jengelh@inai.de
- Request matching libmirage version for build
* Sun Jul 13 2014 sor.alexei@meowr.ru
- Update to new upstream release 3.0.0
  * The CDEmu daemon now has experimental emulation of CD-R and
  DVD+R disc recording, and daemon/client protocol was extended
  to allow transmission of image writer parameters descriptions
  from daemon to client and parameters' values back from client
  to daemon.
- Remove logfile.diff patch
- Add /dev/vhba_ctl read-write access udev rule
* Sun Nov 24 2013 jengelh@inai.de
- Update to new upstream release 2.1.1
  * allow bad sector verification to be turned off (which is now
  default) in order to increase device throughput
  * DPM emulation is now turned off by default as well
  * make sure that EDC and subchannel verification is never performed
  for generated data
* Sun Jun  9 2013 jengelh@inai.de
- Update to new upstream release 2.1.0
  * Use non-blocking I/O on VHBA control device, implemented device
  restart on kernel/userspace I/O errors
  * Added support for device addition/removal. To preserve device
  numbering, devices can only be appended, and only the last device
  can be removed.
  * Auto-started daemon now creates only a single device by default.
  * Fixed device ID reported by INQUIRY, where last letters were
  missing
  * Session autostart script now uses "default" instead of "pulse"
  for audio driver.
  * If audio device initialization fails, fallback to "null" instead
  of just stopping the playback thread.
* Sat Apr 13 2013 jengelh@inai.de
- Resolve build failure with glib 2.36 by allowing deprecated
  functions for the time being (-UG_DISABLE_DEPRECATED)
* Sat Dec 22 2012 jengelh@inai.de
- Update to new upstream release 2.0.0 (up from 1.5.0)
  * Support for ISZ, CSO, DMG, GBI, ECM, gzip and xz formats
  * Partial support for 1-track MDX
- Resolves a problem with autostarting cdemu-daemon
  (bnc#809181, bnc#809862)
* Mon Nov 19 2012 jengelh@inai.de
- Remove cdemud-launch helper, this caused too much confusion.
* Tue May 29 2012 jengelh@inai.de
- Remove dbus autostart and systemd unit file for system-bus mode.
  Place system logfile in proper place (bnc#764063)
* Tue May  8 2012 jengelh@inai.de
- Initial package for build.opensuse.org
